@@ -7,6 +7,7 @@
 #'of 1 meter and the grid values are separated by 10 meters, `zscale` would be 10.
 #'@param cutoff Default `0.999`. The lower limit of the z-component of the unit normal vector to be classified as water.
 #'@param min_area Default length(heightmap)/400. Minimum area (in units of the height matrix x and y spacing) to be considered a body of water.
+#'@param max_height Default `NULL`. If passed, this number will specify the maximum height a point can be considered to be water.
 #'@param normalvectors Default `NULL`. Pre-computed array of normal vectors from the `calculate_normal` function. Supplying this will speed up water detection.
 #'@param keep_groups Default `FALSE`. If `TRUE`, the matrix returned will retain the numbered grouping information.
 #'@param progbar Default `FALSE`. If `TRUE`, turns on progress bar.
@@ -24,7 +25,9 @@
 #'  add_water(detect_water(island_volcano, min_area = 400),color="imhof3") %>%
 #'  plot_map()
 detect_water = function(heightmap, zscale = 1, cutoff = 0.999, 
-                        min_area=length(heightmap)/400 ,normalvectors=NULL,
+                        min_area=length(heightmap)/400,
+                        max_height = NULL,
+                        normalvectors=NULL,
                         keep_groups=FALSE, progbar = FALSE) {
   if(!is.null(normalvectors)) {
     zmatrix = abs(normalvectors$z)
@@ -45,6 +48,11 @@ detect_water = function(heightmap, zscale = 1, cutoff = 0.999,
     zmatrix[nrow(zmatrix),] = 0
     zmatrix[,ncol(zmatrix)] = 0
   }
+  if(!is.null(max_height)) {
+    heightmap_padded = matrix(max_height+1,nrow(heightmap)+2,ncol(heightmap)+2)
+    heightmap_padded[2:(nrow(heightmap_padded)-1),2:(ncol(heightmap_padded)-1)] = heightmap
+    zmatrix[t(heightmap_padded) > max_height] = 0
+  }
   flipud = function(x) {
     x[nrow(x):1,]
   }
