@@ -28,6 +28,8 @@
 #'@param fov Default `0`--isometric. Field-of-view angle.
 #'@param zoom Default `1`. Zoom factor.
 #'@param background Default `grey10`. Color of the background.
+#'@param calculate_normals Default `TRUE`. If `FALSE`, will not calculate per-vertex normals. Can also pass the
+#'output of the function `calculate_normals` to use pre-computed normals.
 #'@param windowsize Default `600`. Position, width, and height of the `rgl` device displaying the plot. 
 #'If a single number, viewport will be a square and located in upper left corner. 
 #'If two numbers, (e.g. `c(600,800)`), user will specify width and height separately. 
@@ -96,7 +98,7 @@ plot_3d = function(hillshade, heightmap, zscale=1, baseshape="rectangle",
                    waterlinecolor=NULL, waterlinealpha = 1, 
                    linewidth = 2, lineantialias = FALSE,
                    theta=45, phi = 45, fov=0, zoom = 1, 
-                   background="white", windowsize = 600, ...) {
+                   background="white", calculate_normals = TRUE, windowsize = 600, ...) {
   #setting default zscale if montereybay is used and tell user about zscale
   argnameschar = unlist(lapply(as.list(sys.call()),as.character))[-1]
   argnames = as.list(sys.call())
@@ -169,12 +171,12 @@ plot_3d = function(hillshade, heightmap, zscale=1, baseshape="rectangle",
     x[nrow(x):1,]
   }
   if(class(hillshade) == "array") {
-    hillshade[,,1] = flipud(hillshade[,,1])
-    hillshade[,,2] = flipud(hillshade[,,2])
-    hillshade[,,3] = flipud(hillshade[,,3])
+    # hillshade[,,1] = flipud(hillshade[,,1])
+    # hillshade[,,2] = flipud(hillshade[,,2])
+    # hillshade[,,3] = flipud(hillshade[,,3])
   }
   if(class(hillshade) == "matrix") {
-    hillshade = hillshade[,ncol(hillshade):1]
+    # hillshade = hillshade[,ncol(hillshade):1]
   }
   if(is.null(heightmap)) {
     stop("heightmap argument missing--need to input both hillshade and original elevation matrix")
@@ -224,7 +226,28 @@ plot_3d = function(hillshade, heightmap, zscale=1, baseshape="rectangle",
   }
   tempmap = tempfile()
   save_png(hillshade,tempmap)
-  rgl.surface(1:nrow(heightmap),-(1:ncol(heightmap)),heightmap[,ncol(heightmap):1]/zscale,texture=paste0(tempmap,".png"),lit=FALSE,ambient = "#000001")
+  precomputed = FALSE
+  if(is.list(calculate_normals)) {
+    normals = calculate_normals
+    calculate_normals = TRUE
+    precomputed = TRUE
+  }
+  if(calculate_normals) {
+    if(!precomputed) {
+      normals = calculate_normal(heightmap,zscale=zscale)
+    }
+    normalsx = (t(normals$x[c(-1,-nrow(normals$x)),c(-1,-ncol(normals$x))]))
+    normalsy = (t(normals$z[c(-1,-nrow(normals$z)),c(-1,-ncol(normals$z))]))
+    normalsz = (t(normals$y[c(-1,-nrow(normals$y)),c(-1,-ncol(normals$y))]))
+    rgl.surface(x=1:nrow(heightmap)-nrow(heightmap)/2,z=(1:ncol(heightmap)-ncol(heightmap)/2),
+                y=heightmap/zscale,
+                normal_x = normalsz, normal_y = normalsy, normal_z = -normalsx,
+                texture=paste0(tempmap,".png"),lit=FALSE,ambient = "#000001")
+  } else {
+    rgl.surface(x=1:nrow(heightmap)-nrow(heightmap)/2,z=(1:ncol(heightmap)-ncol(heightmap)/2),
+                y=heightmap/zscale,
+                texture=paste0(tempmap,".png"),lit=FALSE,ambient = "#000001")
+  }
   bg3d(color = background,texture=NULL)
   rgl.viewpoint(zoom=zoom,phi=phi,theta=theta,fov=fov)
   par3d(windowRect = windowsize,...)
@@ -232,6 +255,7 @@ plot_3d = function(hillshade, heightmap, zscale=1, baseshape="rectangle",
     make_base(heightmap,basedepth=soliddepth,basecolor=solidcolor,zscale=zscale)
   }
   if(!is.null(solidlinecolor) && solid) {
+    rgl::rgl.material(color=solidlinecolor, lit=FALSE)
     make_lines(heightmap,basedepth=soliddepth,linecolor=solidlinecolor,zscale=zscale,linewidth = linewidth)
   }
   if(shadow) {
@@ -242,8 +266,10 @@ plot_3d = function(hillshade, heightmap, zscale=1, baseshape="rectangle",
   }
   if(!is.null(waterlinecolor) && water) {
     if(all(!is.na(heightmap))) {
-      make_lines(heightmap,basedepth=waterdepth,linecolor=waterlinecolor,zscale=zscale,linewidth = linewidth,alpha=waterlinealpha,solid=FALSE)
+      rgl::rgl.material(color=waterlinecolor,lit=FALSE)
+      make_lines(fliplr(heightmap),basedepth=waterdepth,linecolor=waterlinecolor,zscale=zscale,linewidth = linewidth,alpha=waterlinealpha,solid=FALSE)
     }
+    rgl::rgl.material(color=waterlinecolor,lit=FALSE)
     make_waterlines(heightmap,waterdepth=waterdepth,linecolor=waterlinecolor,zscale=zscale,alpha=waterlinealpha,linewidth=linewidth,antialias=lineantialias)
   }
 }
\ No newline at end of file
